"""
Python wrapper for Hacker News API.
@author Anirudh Bhat
@email abhat38@gmail.com
"""

__title__ = 'hacker_news'
__author__ = 'Anirudh Bhat'
__license__ = 'MIT'
__copyright__ = 'Copyright 2015 Anirudh Bhat'

from hn import *